if (requireNamespace("testthat", quietly = TRUE)) {
  library("testthat")
  library("checkmate")
  library("mlr3tuningspaces")
  test_check("mlr3tuningspaces")
}
